==> paraview_5.10.0~rc1.orig.tar.xz: paraview-5.10.0~rc1/Qt/Widgets/pqHighlightableToolButton.h <==
/*=========================================================================

   Program: ParaView
   Module:  pqHighlightableToolButton.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqHighlightableToolButton_h
#define pqHighlightableToolButton_h

#include "pqWidgetsModule.h"
#include <QPalette>
#include <QToolButton>

/**
 * @class pqHighlightableToolButton
 * @brief QToolButton with ability to highlight the button.
 *
 * pqHighlightableToolButton is similar to pqHighlightablePushButton except that
 * is a subclass of QToolButton  instead of QPushButton.
 */
class PQWIDGETS_EXPORT pqHighlightableToolButton : public QToolButton
{
  Q_OBJECT
  typedef QToolButton Superclass;

public:
  pqHighlightableToolButton(QWidget* parent = nullptr);
  virtual ~pqHighlightableToolButton();

public Q_SLOTS:
  /**
   * Slots to highlight (or clear the highlight).
   */
  void highlight(bool clear = false);
  void clear() { this->highlight(true); }

private:
  Q_DISABLE_COPY(pqHighlightableToolButton);
  QPalette ResetPalette;
};

#endif

==> paraview_5.11.0+dfsg.orig.tar.xz: paraview-5.11.0+dfsg/Qt/Widgets/pqHighlightableToolButton.h <==
/*=========================================================================

   Program: ParaView
   Module:  pqHighlightableToolButton.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqHighlightableToolButton_h
#define pqHighlightableToolButton_h

#include "pqWidgetsModule.h"
#include <QPalette>
#include <QToolButton>

/**
 * @class pqHighlightableToolButton
 * @brief QToolButton with ability to highlight the button.
 *
 * pqHighlightableToolButton is similar to pqHighlightablePushButton except that
 * is a subclass of QToolButton  instead of QPushButton.
 */
class PQWIDGETS_EXPORT pqHighlightableToolButton : public QToolButton
{
  Q_OBJECT
  typedef QToolButton Superclass;

public:
  pqHighlightableToolButton(QWidget* parent = nullptr);
  ~pqHighlightableToolButton() override;

public Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
  /**
   * Slots to highlight (or clear the highlight).
   */
  void highlight(bool clear = false);
  void clear() { this->highlight(true); }

private:
  Q_DISABLE_COPY(pqHighlightableToolButton);
  QPalette ResetPalette;
};

#endif
